c
c#######################################################################
c
c     Include file 'globcst.inc' for ARPS 3.0
c
c     This file contains most of the model run control parameters
c     and parameters used by various physics packages.
c
c     These parameters are allocated in named common blocks 
c     therefore accessible to subroutines that include this file.
c
c#######################################################################
c
c                           Copyright (c) 1992                          
c             Center for the Analysis and Prediction of Storms          
c               University of Oklahoma.  All rights reserved.           
c     
c#######################################################################
c 
c     AUTHER: Ming Xue
c     10/01/1991
c
c     MODIFICATION HISTORY:
c
c     5/03/1992 (M. Xue and K. Droegemeier)
c       Major restructuring. Some parameter names changed.
c
c     7/21/1992 (Ming Xue)
c       Added parameters for energy statistics calcualtions, initial 
c       random perturbation option, model run mode controls and 
c       additional history dump format.
c
c#######################################################################
c

c
c#######################################################################
c
c     runname: a character string summarizing the configurations of this
c     run. The initial 6 characters will be used to construct the
c     history data and restart data dump file names.      
c
c#######################################################################
c
      character runname*80    ! Name of this run
      integer nocmnt          ! Number of comment lines
      character cmnt(50)*80   ! String of comments on this model run
      common /arpsc010/ runname ! the name of this run.
      common /arpsc011/ cmnt
      common /arpsc011mp/ nocmnt  ! comment lines 
c
c#######################################################################
c
c     Control parameters for model initialization 
c
c#######################################################################
c
      integer runmod  ! Option switch for model run mode.
                      ! = 1, model is run in 3-D mode 
                      ! = 2, model is run in 2-D mode in x-z place 
                      ! = 3, model is run in 2-D mode in y-z place
                      ! = 4, model is run in 1-D mode in z direction

      real grdscl     ! The grid size scale who definition depends on 
                      ! the model run mode

      common /arpsc020/ runmod, grdscl
c
c#######################################################################
c
c     Control parameters for model initialization 
c
c#######################################################################
c
      integer initopt ! Option parameter for model initialization.
                      ! = 1, self initialization (e.g. analytical field)
                      ! = 2, Restart run, initialize from restart file. 
                      ! = 3, Initialize from external data set.         

      integer pt0opt  ! Option to specify the type of initial potential
                      ! temperature pertrubation for initopt=1 case.
                      ! = 1, initial peturbation is bubble-shaped,
                      ! = 2, initial peturbation has a random distribution.

      character inifile*80 
                      ! File name of initial fields data for option 3
      integer inifunt ! Fortran I/O unit number for initial data input.

      common /arpsc030/ initopt, pt0opt, inifunt
      common /arpsc031/ inifile

      real ptpert0    ! The magnitude of initial potential temperature 
                      ! perturbation (K)

      real pt0radx    ! The radius of bubble in x-direction. 
      real pt0rady    ! The radius of bubble in y-direction.
      real pt0radz    ! The radius of bubble in z-direction.
      real pt0ctrx    ! The x corrdinate of the bubble center.
      real pt0ctry    ! The y corrdinate of the bubble center.
      real pt0ctrz    ! The z corrdinate of the bubble center.

      common /arpsc040/ ptpert0,pt0radx,pt0rady,pt0radz,
     :                        pt0ctrx,pt0ctry,pt0ctrz

      integer restrt  ! Parameter designating if this is a restart run.
                      ! For a non-restart run restrt = 1;
                      ! for a restart run restrt = 0.

      integer rstiunt      ! Fortran I/O unit used by restart data read.
      character rstinf*80  ! File name of restart input data.
c
c#######################################################################
c
c     Environmental sounding file name and Fortran I/O input unit.
c
c#######################################################################
c
      character sndfile*80 ! Name of the input sounding file.
      integer sfunit       ! Fortran I/O unit used by sounding input.

      common /arpsc050/ sndfile
      common /arpsc051/ sfunit
c
c#######################################################################
c
c     Model grid parameters.
c
c#######################################################################
c
      real dx         ! Grid spacing in x-direction in computational 
                      ! as well as in physical space (meter)
      real dy         ! Grid spacing in y-direction in computational 
                      ! as well as in physical space (meter)
      real dz         ! Grid spacing in vertical direction in 
                      ! transformed computataional space.
      real dxinv      ! Reciprocal of dx (i.e. 1/dx)
      real dyinv      ! Reciprocal of dy (i.e. 1/dy)
      real dzinv      ! Reciprocal of dz (i.e. 1/dz)

      common /arpsc060/ dx,dy,dz,dxinv,dyinv,dzinv 

      real xl         ! Physcal scale of the model domain in x-direction
                      ! (meter). In uniform spacing case xl = (nx-3)*dx.
      real yl         ! Physcal scale of the model domain in y-direction
                      ! (meter). In uniform spacing case yl = (ny-3)*dy.
      real zh         ! Physcal scale of the model domain in z-direction
                      ! (meter). In uniform spacing case zh = (nz-3)*dz.

      common /arpsc070/ xl,yl,zh

c
c#######################################################################
c
c     Definition of acoustic/sound wave speed to be used in the 
c     pressure eqaution. 
c
c#######################################################################
c
      integer csopt   ! Parameter determine the definition of sound
                      ! wave speed used in the pressure equation. 
                      ! csopt = 1, csound = cp/cv * rd * T
                      ! csopt = 2, csound = cp/cv * rd * T * csfactr
                      ! csopt = 3, csound = specfied constant. 
      real    csfactr ! A multiplication factor for sound speed.
      real    csound  ! User specified constant sound speed. 

      common /arpsc080/ csopt, csfactr, csound
c
c#######################################################################
c
c     Model integration time step and integration control parameters.
c
c#######################################################################
c
      real dtbig      ! Model integration time step.
      real dtsml      ! Small time step size for the acoustic wave 
                      ! integrations.

      real    tstart  ! The time when the model is initialized. 
      real    tstop   ! The time when time integration is to be stoped.
      real    curtim  ! Current model time.

      integer nstep   ! The number time steps already taken.
      integer nsteps  ! The total number of time steps to be taken 
                      ! in this run.
      integer nsmstp  ! The number of small acoustic wave time 
                      ! integration steps per large time step.

      common /arpsc090/ dtbig, tstart, tstop, nstep, nsteps, curtim
      common /arpsc100/ nsmstp, dtsml
c
c#######################################################################
c
c     Robert-Asselin time filter coefficient for leapfrog time 
c     integration:
c
c#######################################################################
c
      real flteps     ! coef. of Robert-Asselin time filter 
                      ! (non-dimensional).

      common /arpsc110/ flteps
c
c#######################################################################
c
c     Parameters for subgrid-scale turbulent mixing.
c
c#######################################################################
c
      integer tmixopt ! Control parameter for turbulent mixing options.
                      ! tmixopt =
                      ! 0, zero turbulent mixing,
                      ! 1, constant mixing coefficient km = tmixcst,
                      ! 2, Smagorinsky formulation of mixing coeff.,
                      ! 3, Smagorinsky mixing coefficient 
                      !      plus a constant coeffcient tmixcst.
 
      real prantl     ! Turbulent prandtl number, prantl = km/kh.
      real tmixcst    ! Value of the constant mixing coefficient.
c
      common /arpsc120/ tmixopt, prantl ,tmixcst
c
c#######################################################################
c
c     Parameters for computational mixing.
c
c#######################################################################
c
      integer kcmix2  ! control switch for 2nd order comp. mixing. =0 or 1.
      real cfcmh2     ! coef. of 2nd order horizontal computational mixing
      real cfcmv2     ! coef. of 2nd order vertical computational mixing

      integer kcmix4  ! control switch for 4th order comp. mixing. =0 or 1.
      real cfcmh4     ! coef. of 4th order horizontal computational mixing
      real cfcmv4     ! coef. of 4th order vertical computational mixing

      common /arpsc130/ kcmix2, cfcmh2,cfcmv2, kcmix4, cfcmh4,cfcmv4
c
c#######################################################################
c
c     Parameter for upper level Rayleigh damping.
c
c#######################################################################
c
      integer raydmp  ! Control parameter for Rayleigh damping.
                      ! raydmp = 1, damping is on; = 0, damping id off.
      real zbrdmp     ! Height of the bottom of Rayleigh damping 
                      ! (sponge) layer (meter).
      real ztrdmp     ! Height of the top of Rayleigh damping 
                      ! (sponge) layer (meter).
      real cfrdmp     ! Rayleigh damping coefficient (1/second).
 
      common /arpsc140/ raydmp, zbrdmp, ztrdmp, cfrdmp
c
c#######################################################################
c
c     Parameters for acoustic wave divergence damping
c
c#######################################################################
c
      integer divdmp  ! Control parameter for acoustic wave divergence 
                      ! damping. divdmp = 1, div. damping is on; 
                      !                 = 0, div. damping is off.
      real cdvdmp     ! coef. of the divergence damping term. (m**2/s). 
 
      common /arpsc150/ divdmp, cdvdmp 
c
c#######################################################################
c
c     Control parameter for moist and ice microphysics processes. 
c
c#######################################################################
c
      integer mphyopt ! Parameter specifying the option of microphysics
                      ! parameterization scheme to be chosed.
                      ! mphyopt = 0, No microphysics. 
                      ! mphyopt = 1, Kessler type warming rain microphysics.
                      ! mphyopt = 2, More elaborate scheme - GEMS of Straka. 
                      !              Not implemented yet.

      integer moist   ! Control parameter for moist processes in the
                      ! model run. 
                      !
                      ! If moist = 0, the run is dry, all processes 
                      ! related to moisture are switched off.
                      ! If moist = 1, moist processes are activated.

      integer ice     ! Control parameter for ice microphysical 
                      ! processes in the model run.
                      !
                      ! If ice = 0, all processes related to ice are 
                      ! switched off.  
                      ! If ice = 1, ice processes are activated.
 
      common /arpsc160/ mphyopt, moist, ice
c
c
c#######################################################################
c
c     Definition of constants used in microphysics parameterizations.
c
c#######################################################################
c
      real autotr     ! Threshold of cloud water mixing ratio 
                      ! for auto-conversion to rain water (kg/kg)
      parameter ( autotr = 1.0e-3 )

      real autort     ! autoconversion rate (1./seconds)
      parameter ( autort = 1.0E-3 )

      real accrrt     ! accretion rate (1./seconds)
      parameter ( accrrt = 2.2 )

      REAL RHO0       ! reference density (kg/meter**3)
      parameter ( rho0 = 1.225 )
  
      real aw, bw     ! parameters used in Teten's formula for 
                      ! saturation specific humidity
      parameter ( aw = 17.27, bw = 35.86 )
c
c
c#######################################################################
c
c     The x and y component of the domain translation speed 
c     relative to the earth.
c
c#######################################################################
c
      real umove      ! Speed of model domain translation in x direction.
      real vmove      ! Speed of model domain translation in y direction.
      common /arpsc170/ umove, vmove 
c
c#######################################################################
c
c     Parameters for surface physics processes. 
c
c#######################################################################
c
      integer sfcphy  ! Control parameter specifying the option of
                      ! surface physics parameterizations. 
                      ! sfcphy = 0, no surface physics parameterization
                      ! sfcphy = 1, simple bulk aerodynamic formulation. 
 
      real cdm        ! bulk aerodynamic drag coefficient for momentum
      real cdh        ! bulk aerodynamic drag coefficient for heat flux 
      real cdq        ! bulk aerodynamic drag coefficient for moisture flux 
                      ! cdm, cdh and cdq are all non-dimensional.
 
      common /arpsc180/ sfcphy, cdm,cdh,cdq
c
c#######################################################################
c
c     The Coriolis parameters
c
c#######################################################################
c
      integer coriopt ! Coriolis term definition option
      real fcorio1    ! Coriolis parameter (1/s)
      real fcorio2    ! Coriolis parameter (1/s)
      real latitud    ! Earth latitude of the model center (degree)
      common /arpsc190/ coriopt, fcorio1, fcorio2, latitud
c
c#######################################################################
c
c     The name of the directory into which output files will be written:
c
c#######################################################################
c
      character dirname*80 ! The name of output directory
      integer   ldirnam    ! The length of the directory name string

      common /arpsc200/ ldirnam
      common /arpsc201/ dirname
c
c#######################################################################
c
c     Parameters controling the model output
c
c#######################################################################
c
      integer nfmtprt ! time steps    between formatted print out
      real    tfmtprt ! time interval between formatted print out

      integer nmaxmin ! time steps    between max/min statistics calc.
      real    tmaxmin ! time interval between max/min statistics calc.

      integer nenergy ! time steps    between energy statistics calc.
      real    tenergy ! time interval between energy statistics calc.

      integer nrstout ! time steps    between restart data dumps
      real    trstout ! time interval between restart data dumps

      integer nhisdmp ! time steps    between history data dumps
      real    thisdmp ! time interval between history data dumps

      common /arpsc210/ nfmtprt, nmaxmin, nenergy, nrstout, nhisdmp
      common /arpsc220/ tfmtprt, tmaxmin, tenergy, trstout, thisdmp
c
c
      integer grdout  ! Parameter controlling grid output.
                      ! grdout = 0 or 1.
      integer basout  ! Parameter controlling base state field output.
                      ! basout = 0 or 1.
      integer varout  ! Parameter controlling mass&wind perturbation
                      ! field output.  varout = 0 or 1.
      integer mstout  ! Parameter controlling output of moist variables
                      ! qv, qc, qr, qi, qs and qh.
      integer iceout  ! Parameter controlling output of ice variables
                      ! qi, qs and qh. iceout = 1 or 0 for yes or no.
      integer trbout  ! Parameter controlling turbulence field (km) output.
                      ! trbout = 0 or 1.

      common /arpsc230/ grdout, basout, varout, mstout, iceout, trbout

c
c#######################################################################
c
c     Parameters for history data dump and other data output.
c
c#######################################################################
c
      integer hdmpfmt ! Parameter specifying format of history data dump
                      ! hdmpfmt = 0, no data dump is produced; 
                      ! hdmpfmt = 1, unformatted binary data dump;
                      ! hdmpfmt = 2, formatted ascii data dump;
                      ! hdmpfmt = 3, NCSA HDF format data dump;
                      ! hdmpfmt = 4, Compressed binary data dump; 
                      ! hdmpfmt = 5, Dump for Savi3D visualization package. 
 
      integer nchdmp       ! Fortran I/O channel for history data dump.
      character  hdmpfn*80 ! History data dump file name.
      integer    ldmpf     ! Length of the history data dump file name

      common /arpsc240/ hdmpfmt ,nchdmp 
      common /arpsc250/ hdmpfn
      common /arpsc251/ ldmpf
c
c#######################################################################
c
c     Parameters for model restart data dump. 
c
c#######################################################################
c
      integer rstount      ! Fortran I/O unit used by restart data dump.
      character rstoutf*80 ! File name of restart data dump.
c
      common /arpsc260/ restrt, rstount, rstiunt
      common /arpsc270/ rstoutf
      common /arpsc271/ rstinf
c
c#######################################################################
c
c     The Fortran I/O channel (unit) used by max/min statistics output.
c
c#######################################################################
c
      integer nchmax  ! Fortran I/O channel for max/min statistics output.
      common /arpsc280/ nchmax 
c
c#######################################################################
c
c     The Fortran I/O channel (unit) used by energy statistics output 
c
c#######################################################################
c
      integer ncheng  ! Fortran I/O channel for energy statistics output.
      common /arpsc290/ ncheng 
c
c#######################################################################
c
c     Parameters used by Savi3D. 
c
c#######################################################################
c
      integer grafh   ! Grafhandle used by savi3D
      integer gridh   ! Gridhandle used by savi3D
      common /arpsc300/ grafh, gridh
